/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dolphinscheduler.dao.datasource;

import org.apache.dolphinscheduler.common.Constants;
import org.apache.dolphinscheduler.common.enums.DbConnectType;
import org.apache.dolphinscheduler.common.enums.DbType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * data source of Oracle
 */
public class OracleDataSource extends BaseDataSource {

    private DbConnectType type;

    public DbConnectType getType() {
        return type;
    }

    public void setType(DbConnectType type) {
        this.type = type;
    }

    /**
     * @return driver class
     */
    @Override
    public String driverClassSelector() {
        return Constants.COM_ORACLE_JDBC_DRIVER;
    }

    /**
     * gets the JDBC url for the data source connection
     * @return jdbc url
     */
    @Override
    public String getJdbcUrl() {
        String jdbcUrl = getAddress();
        if (jdbcUrl.lastIndexOf("/") != (jdbcUrl.length() - 1)) {
            jdbcUrl += "/";
        }
        return jdbcUrl;
    }

    /**
     * @return db type
     */
    @Override
    public DbType dbTypeSelector() {
        return DbType.ORACLE;
    }

}
